@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,15 +52,16 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-
 import java.sql.*;
+import org.junit.Assert;
+import org.junit.Assume;
+import org.junit.Test;
 
 public class AutoReconnectTest extends BaseTest {
 
   @Test
   public void autoReconnect() throws SQLException, InterruptedException {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     try (Connection conn = setConnection("&autoReconnect")) {
       Statement stmt = conn.createStatement();
       stmt.executeQuery("SELECT 1");
@@ -70,9 +71,9 @@ public class AutoReconnectTest extends BaseTest {
 
       try {
         stmt.executeQuery("SELECT 2");
-      } catch (SQLTransientConnectionException e) {
-        Assert.fail("Must have send a SQLNonTransientConnectionException !");
       } catch (SQLNonTransientConnectionException e) {
+        Assert.fail("Must have send a SQLTransientConnectionException !");
+      } catch (SQLTransientConnectionException e) {
         try {
           stmt.executeQuery("SELECT 3");
         } catch (SQLException ee) {
@@ -88,7 +89,7 @@ public class AutoReconnectTest extends BaseTest {
 
   @Test
   public void autoReconnectPing() throws SQLException, InterruptedException {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     try (Connection conn = setConnection("&autoReconnect")) {
       Statement stmt = conn.createStatement();
       stmt.executeQuery("SELECT 1");
