@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,26 +52,27 @@
 
 package org.mariadb.jdbc;
 
-import com.sun.jna.*;
-import org.junit.*;
-import org.junit.rules.*;
-import org.junit.runner.*;
-import org.mariadb.jdbc.failover.*;
-import org.mariadb.jdbc.internal.failover.*;
-import org.mariadb.jdbc.internal.protocol.*;
-import org.mariadb.jdbc.util.*;
-
-import java.io.*;
-import java.lang.Thread.*;
-import java.lang.reflect.*;
-import java.net.*;
-import java.sql.*;
-import java.text.*;
-import java.util.*;
-import java.util.regex.*;
-
 import static org.junit.Assert.*;
 
+import com.sun.jna.Platform;
+import java.io.*;
+import java.lang.Thread.State;
+import java.lang.reflect.Method;
+import java.net.InetAddress;
+import java.net.UnknownHostException;
+import java.sql.*;
+import java.text.DecimalFormat;
+import java.text.NumberFormat;
+import java.util.*;
+import org.junit.*;
+import org.junit.rules.TestRule;
+import org.junit.rules.TestWatcher;
+import org.junit.runner.Description;
+import org.mariadb.jdbc.failover.TcpProxy;
+import org.mariadb.jdbc.internal.failover.AbstractMastersListener;
+import org.mariadb.jdbc.internal.protocol.Protocol;
+import org.mariadb.jdbc.util.Options;
+
 /**
  * Base util class. For testing mvn test -DdbUrl=jdbc:mariadb://localhost:3306/testj?user=root
  * -DlogLevel=FINEST
@@ -79,8 +80,28 @@ import static org.junit.Assert.*;
 @Ignore
 @SuppressWarnings("Annotator")
 public class BaseTest {
+  protected static String mDefUrl;
+
+  static {
+    try (InputStream inputStream =
+        BaseTest.class.getClassLoader().getResourceAsStream("conf.properties")) {
+      Properties prop = new Properties();
+      prop.load(inputStream);
+      mDefUrl =
+          String.format(
+              "jdbc:mariadb://%s:%s/%s?user=%s&password=%s&%s",
+              prop.getProperty("DB_HOST"),
+              prop.getProperty("DB_PORT"),
+              prop.getProperty("DB_DATABASE"),
+              prop.getProperty("DB_USER"),
+              prop.getProperty("DB_PASSWORD"),
+              prop.getProperty("DB_OTHER"));
+
+    } catch (IOException io) {
+      io.printStackTrace();
+    }
+  }
 
-  protected static final String mDefUrl = "jdbc:mariadb://localhost:3306/testj?user=root";
   private static final Set<String> tempTableList = new HashSet<>();
   private static final Set<String> tempViewList = new HashSet<>();
   private static final Set<String> tempProcedureList = new HashSet<>();
@@ -94,6 +115,7 @@ public class BaseTest {
   protected static String database;
   protected static String username;
   protected static String password;
+  protected static Options options;
   protected static String parameters;
   protected static boolean testSingleHost;
   protected static Connection sharedConnection;
@@ -189,7 +211,7 @@ public class BaseTest {
     testSingleHost = Boolean.parseBoolean(System.getProperty("testSingleHost", "true"));
 
     if (testSingleHost) {
-      urlParser = UrlParser.parse(url + "&pool=true&maxPoolSize=2&minPoolSize=1");
+      urlParser = UrlParser.parse(url); // + "&pool=true&maxPoolSize=2&minPoolSize=1");
       if (urlParser.getHostAddresses().size() > 0) {
         hostname = urlParser.getHostAddresses().get(0).host;
         port = urlParser.getHostAddresses().get(0).port;
@@ -200,6 +222,7 @@ public class BaseTest {
       database = urlParser.getDatabase();
       username = urlParser.getUsername();
       password = urlParser.getPassword();
+      options = urlParser.getOptions();
       int separator = url.indexOf("//");
       String urlSecondPart = url.substring(separator + 2);
       int dbIndex = urlSecondPart.indexOf("/");
@@ -215,13 +238,9 @@ public class BaseTest {
         additionalParameters = null;
       }
       if (additionalParameters != null) {
-        String regex = "(\\/[^\\?]*)(\\?.+)*|(\\?[^\\/]*)(\\/.+)*";
-        Pattern pattern = Pattern.compile(regex);
-        Matcher matcher = pattern.matcher(additionalParameters);
-        if (matcher.find()) {
-          String options1 = (matcher.group(2) != null) ? matcher.group(2).substring(1) : "";
-          String options2 = (matcher.group(3) != null) ? matcher.group(3).substring(1) : "";
-          parameters = (options1.isEmpty()) ? options2 : options1;
+        parameters = "";
+        if (additionalParameters.indexOf("?") >= 0) {
+          parameters = additionalParameters.substring(additionalParameters.indexOf("?") + 1);
         }
       } else {
         parameters = null;
@@ -251,11 +270,7 @@ public class BaseTest {
             + port
             + "/"
             + ((database == null) ? "" : database);
-    connUri =
-        connU
-            + "?"
-            + parameters
-            + (password != null && !"".equals(password) ? "&password=" + password : "");
+    connUri = connU + "?" + parameters;
     connDnsUri =
         "jdbc:mariadb://mariadb.example.com:"
             + port
@@ -513,8 +528,21 @@ public class BaseTest {
     } catch (IOException e) {
       e.printStackTrace();
     }
+    String[] splitValue = connUri.split("/");
+    String[] subarray =
+        Arrays.asList(splitValue).subList(3, splitValue.length).toArray(new String[0]);
+    String dbAndParameters = String.join("/", subarray);
 
-    return openConnection("jdbc:mariadb://" + sockethosts + "/" + connUri.split("/")[3], info);
+    return openConnection(
+        "jdbc:mariadb://"
+            + sockethosts
+            + "/"
+            + dbAndParameters
+            + ((options.useSsl != null)
+                ? "&useSsl" + options.useSsl + "&disableSslHostnameVerification"
+                : "")
+            + ((options.serverSslCert != null) ? "&serverSslCert=" + options.serverSslCert : ""),
+        info);
   }
 
   /**
@@ -535,6 +563,10 @@ public class BaseTest {
     proxy.setDelay(millissecond);
   }
 
+  public void forceCloseProxy() {
+    proxy.forceClose();
+  }
+
   public void removeDelayProxy() {
     proxy.removeDelay();
   }
@@ -612,6 +644,8 @@ public class BaseTest {
             + "?user="
             + username
             + (password != null && !"".equals(password) ? "&password=" + password : "")
+            + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+            + ((options.serverSslCert != null) ? "&serverSslCert=" + options.serverSslCert : "")
             + parameters,
         null);
   }
