@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,16 +52,16 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-import org.mariadb.jdbc.internal.util.scheduler.*;
+import static org.junit.Assert.*;
 
-import java.net.*;
-import java.nio.charset.*;
+import java.net.InetAddress;
+import java.net.UnknownHostException;
+import java.nio.charset.StandardCharsets;
 import java.sql.*;
 import java.util.*;
-import java.util.concurrent.*;
-
-import static org.junit.Assert.*;
+import java.util.concurrent.Executor;
+import org.junit.*;
+import org.mariadb.jdbc.internal.util.scheduler.SchedulerServiceProviderHolder;
 
 public class ConnectionTest extends BaseTest {
 
@@ -467,6 +467,24 @@ public class ConnectionTest extends BaseTest {
     }
   }
 
+  @Test
+  public void testRst() throws Throwable {
+    Assume.assumeFalse(sharedIsAurora());
+    Properties props = new Properties();
+    props.setProperty("enablePacketDebug", "true");
+    props.setProperty("autoReconnect", "true");
+    try (Connection connection = createProxyConnection(props)) {
+      assertTrue(connection.isValid(1)); // 1 second
+      forceCloseProxy();
+      connection.createStatement().execute("SELECT 1");
+      fail("must have failed");
+    } catch (SQLException sqle) {
+      assertTrue(sqle.getCause().getCause().getMessage().contains("send at -exchange:"));
+    } finally {
+      closeProxy();
+    }
+  }
+
   @Test(timeout = 15_000L)
   public void testValidFailedTimeout() throws Throwable {
     Properties properties = new Properties();
@@ -564,7 +582,7 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void verificationEd25519AuthPlugin() throws Throwable {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     Assume.assumeTrue(isMariadbServer() && minVersion(10, 2));
     Statement stmt = sharedConnection.createStatement();
 
@@ -586,7 +604,7 @@ public class ConnectionTest extends BaseTest {
     } catch (SQLException sqle) {
       // already existing
     }
-    stmt.execute("GRANT ALL on " + database + ".* to verificationEd25519AuthPlugin");
+    stmt.execute("GRANT SELECT on " + database + ".* to verificationEd25519AuthPlugin");
 
     String url =
         "jdbc:mariadb://"
@@ -659,6 +677,7 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void slaveDownConnection() throws SQLException {
+    Assume.assumeTrue(System.getenv("SKYSQL") == null);
     String url =
         "jdbc:mariadb:replication://"
             + hostname
@@ -671,6 +690,8 @@ public class ConnectionTest extends BaseTest {
             + "?user="
             + username
             + ((password != null) ? "&password=" + password : "")
+            + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+            + ((options.serverSslCert != null) ? "&serverSslCert=" + options.serverSslCert : "")
             + "&retriesAllDown=10&allowMasterDownConnection&connectTimeout=100&socketTimeout=100";
     try (Connection connection = DriverManager.getConnection(url)) {
       Assert.assertFalse(connection.isReadOnly());
@@ -687,7 +708,7 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void multiAuthPlugin() throws Throwable {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     Assume.assumeTrue(isMariadbServer() && minVersion(10, 4, 2));
     Statement stmt = sharedConnection.createStatement();
     try {
@@ -707,7 +728,7 @@ public class ConnectionTest extends BaseTest {
       // already existing
       sqle.printStackTrace();
     }
-    stmt.execute("GRANT ALL on " + database + ".* to mysqltest1@'%'");
+    stmt.execute("GRANT SELECT on " + database + ".* to mysqltest1@'%'");
 
     try (Connection connection =
         openNewConnection(
@@ -745,7 +766,7 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void connectionUnexpectedClose() throws SQLException {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     try (Connection connection =
         DriverManager.getConnection(
             "jdbc:mariadb:failover//"
@@ -757,6 +778,8 @@ public class ConnectionTest extends BaseTest {
                 + "?user="
                 + username
                 + ((password != null) ? "&password=" + password : "")
+                + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+                + ((options.serverSslCert != null) ? "&serverSslCert=" + options.serverSslCert : "")
                 + "&socketTimeout=1000&useServerPrepStmts=true")) {
       Statement stmt = connection.createStatement();
       try {
@@ -798,7 +821,7 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void setReadonlyError() throws SQLException {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     try (Connection connection =
         DriverManager.getConnection(
             "jdbc:mariadb:replication://"
@@ -813,6 +836,8 @@ public class ConnectionTest extends BaseTest {
                 + database
                 + "?user="
                 + username
+                + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+                + ((options.serverSslCert != null) ? "&serverSslCert=" + options.serverSslCert : "")
                 + ((password != null) ? "&password=" + password : ""))) {
       connection.setReadOnly(true);
       long threadId = ((MariaDbConnection) connection).getServerThreadId();
@@ -846,7 +871,7 @@ public class ConnectionTest extends BaseTest {
       sharedConnection.setTypeMap(null);
       fail();
     } catch (SQLFeatureNotSupportedException e) {
-      assertTrue(e.getMessage().contains("Not yet supported"));
+      assertTrue(e.getMessage().contains("TypeMap are not supported"));
     }
 
     assertTrue(sharedConnection.getTypeMap().isEmpty());
@@ -864,21 +889,21 @@ public class ConnectionTest extends BaseTest {
       sharedConnection.createSQLXML();
       fail();
     } catch (SQLFeatureNotSupportedException e) {
-      assertTrue(e.getMessage().contains("Not supported"));
+      assertTrue(e.getMessage().contains("SQLXML type is not supported"));
     }
 
     try {
       sharedConnection.createArrayOf("", null);
       fail();
     } catch (SQLFeatureNotSupportedException e) {
-      assertTrue(e.getMessage().contains("Not yet supported"));
+      assertTrue(e.getMessage().contains("Array type is not supported"));
     }
 
     try {
       sharedConnection.createStruct("", null);
       fail();
     } catch (SQLFeatureNotSupportedException e) {
-      assertTrue(e.getMessage().contains("Not yet supported"));
+      assertTrue(e.getMessage().contains("Struct type is not supported"));
     }
     sharedConnection.setSchema("bbb");
     assertNull(sharedConnection.getSchema());
@@ -892,7 +917,7 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void setClientNotConnectError() throws SQLException {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     // only mariadb return a specific error when connection has explicitly been killed
     Assume.assumeTrue(isMariadbServer());
 
@@ -910,7 +935,11 @@ public class ConnectionTest extends BaseTest {
                 + database
                 + "?log&user="
                 + username
-                + ((password != null) ? "&password=" + password : ""))) {
+                + ((password != null) ? "&password=" + password : "")
+                + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+                + ((options.serverSslCert != null)
+                    ? "&serverSslCert=" + options.serverSslCert
+                    : ""))) {
       connection.setReadOnly(true);
       long threadId = ((MariaDbConnection) connection).getServerThreadId();
       connection.setReadOnly(false);
@@ -952,4 +981,50 @@ public class ConnectionTest extends BaseTest {
       assertEquals(10_000, connection2.getNetworkTimeout());
     }
   }
+
+  @Test
+  public void readOnly() throws SQLException {
+    Statement stmt = sharedConnection.createStatement();
+    stmt.execute("CREATE TABLE testReadOnly(id int)");
+    sharedConnection.setAutoCommit(false);
+
+    sharedConnection.setReadOnly(true);
+    stmt.execute("INSERT INTO testReadOnly values (1)");
+    sharedConnection.commit();
+
+    Connection connection = setConnection("&assureReadOnly=true");
+    stmt = connection.createStatement();
+
+    connection.setAutoCommit(false);
+    connection.setReadOnly(true);
+    try {
+      stmt.execute("INSERT INTO testReadOnly values (2)");
+      fail();
+    } catch (SQLException sqle) {
+      assertTrue(sqle.getMessage().contains("Cannot execute statement in a READ ONLY transaction"));
+    }
+    connection.setReadOnly(false);
+    stmt.execute("DROP TABLE testReadOnly");
+  }
+
+  @Test
+  public void connectionAttributes() throws SQLException {
+
+    try (MariaDbConnection conn =
+        (MariaDbConnection) setConnection("&connectionAttributes=test:test1")) {
+      Statement stmt = conn.createStatement();
+      ResultSet rs1 = stmt.executeQuery("SELECT @@performance_schema");
+      rs1.next();
+      if ("1".equals(rs1.getString(1))) {
+        ResultSet rs =
+            stmt.executeQuery(
+                "SELECT * from performance_schema.session_connect_attrs where processlist_id="
+                    + conn.getServerThreadId()
+                    + " AND ATTR_NAME='test'");
+        while (rs.next()) {
+          assertEquals("test1", rs.getString("ATTR_VALUE"));
+        }
+      }
+    }
+  }
 }
