@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -22,12 +22,15 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-
-import java.sql.*;
-
 import static org.junit.Assert.*;
 
+import java.sql.Connection;
+import java.sql.ResultSet;
+import java.sql.SQLException;
+import org.junit.Assume;
+import org.junit.BeforeClass;
+import org.junit.Test;
+
 public class DataSourcePoolTest extends BaseTest {
 
   protected static final String defConnectToIP = null;
@@ -36,11 +39,14 @@ public class DataSourcePoolTest extends BaseTest {
   /** Initialisation. */
   @BeforeClass
   public static void beforeClassDataSourceTest() {
+    Assume.assumeTrue(System.getenv("SKYSQL") == null);
     connectToIP = System.getProperty("testConnectToIP", defConnectToIP);
   }
 
   @Test
   public void testDataSource() throws SQLException {
+    Assume.assumeFalse(options.useSsl != null && options.useSsl);
+
     try (MariaDbPoolDataSource ds =
         new MariaDbPoolDataSource(hostname == null ? "localhost" : hostname, port, database)) {
       try (Connection connection = ds.getConnection(username, password)) {
@@ -51,6 +57,7 @@ public class DataSourcePoolTest extends BaseTest {
 
   @Test
   public void testDataSource2() throws SQLException {
+    Assume.assumeFalse(options.useSsl != null && options.useSsl);
     try (MariaDbPoolDataSource ds =
         new MariaDbPoolDataSource(hostname == null ? "localhost" : hostname, port, database)) {
       try (Connection connection = ds.getConnection(username, password)) {
@@ -61,6 +68,7 @@ public class DataSourcePoolTest extends BaseTest {
 
   @Test
   public void testDataSourceEmpty() throws SQLException {
+    Assume.assumeFalse(options.useSsl != null && options.useSsl);
     try (MariaDbPoolDataSource ds = new MariaDbPoolDataSource()) {
       ds.setDatabaseName(database);
       ds.setPort(port);
@@ -105,7 +113,7 @@ public class DataSourcePoolTest extends BaseTest {
    */
   @Test
   public void setDatabaseNameTest() throws SQLException {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     try (MariaDbPoolDataSource ds =
         new MariaDbPoolDataSource(hostname == null ? "localhost" : hostname, port, database)) {
       try (Connection connection = ds.getConnection(username, password)) {
@@ -153,6 +161,8 @@ public class DataSourcePoolTest extends BaseTest {
   @Test(timeout = 20000) // unless port 3307 can be used
   public void setPortTest() throws SQLException {
     Assume.assumeFalse("true".equals(System.getenv("AURORA")));
+    Assume.assumeFalse(options.useSsl != null && options.useSsl);
+
     try (MariaDbPoolDataSource ds =
         new MariaDbPoolDataSource(hostname == null ? "localhost" : hostname, port, database)) {
       try (Connection connection2 = ds.getConnection(username, password)) {
