@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,15 +52,17 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
+import static org.junit.Assert.*;
 
 import java.io.*;
-import java.math.*;
-import java.net.*;
-import java.nio.charset.*;
+import java.math.BigDecimal;
+import java.math.BigInteger;
+import java.net.URL;
+import java.nio.charset.StandardCharsets;
 import java.sql.*;
-
-import static org.junit.Assert.*;
+import org.junit.Before;
+import org.junit.BeforeClass;
+import org.junit.Test;
 
 public class DatatypeTest extends BaseTest {
 
@@ -1005,6 +1007,8 @@ public class DatatypeTest extends BaseTest {
                 + "?user="
                 + username
                 + ((password != null && !password.isEmpty()) ? "&password=" + password : "")
+                + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+                + ((options.serverSslCert != null) ? "&serverSslCert=" + options.serverSslCert : "")
                 + "&useServerPrepStmts=true")) {
       checkCharactersInsert(connection);
     }
@@ -1018,6 +1022,8 @@ public class DatatypeTest extends BaseTest {
                 + "?user="
                 + username
                 + (password != null && !"".equals(password) ? "&password=" + password : "")
+                + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+                + ((options.serverSslCert != null) ? "&serverSslCert=" + options.serverSslCert : "")
                 + "&useServerPrepStmts=false")) {
       checkCharactersInsert(connection);
     }
