@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,14 +52,18 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-import org.mariadb.jdbc.internal.protocol.*;
-
-import javax.sql.*;
-import java.sql.*;
-
 import static org.junit.Assert.*;
 
+import java.sql.Connection;
+import java.sql.PreparedStatement;
+import java.sql.SQLException;
+import java.sql.Statement;
+import javax.sql.DataSource;
+import org.junit.Assume;
+import org.junit.BeforeClass;
+import org.junit.Test;
+import org.mariadb.jdbc.internal.protocol.Protocol;
+
 public class ErrorMessageTest extends BaseTest {
 
   /**
@@ -83,7 +87,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
     }
@@ -100,17 +103,15 @@ public class ErrorMessageTest extends BaseTest {
           || sharedOptions().useServerPrepStmts
           || sharedOptions().rewriteBatchedStatements) {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
       } else {
         if (!sharedOptions().useBatchMultiSend) {
           assertTrue(
-              "message : " + sqle.getCause().getCause().getMessage(),
+              "message : " + sqle.getCause().getMessage(),
               sqle.getCause()
-                  .getCause()
                   .getMessage()
                   .contains(
                       "INSERT INTO testErrorMessage(test, test2) values (?, ?), "
@@ -118,7 +119,6 @@ public class ErrorMessageTest extends BaseTest {
         } else {
           assertTrue(
               sqle.getCause()
-                  .getCause()
                   .getMessage()
                   .contains(
                       "INSERT INTO testErrorMessage(test, test2) values "
@@ -137,7 +137,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
     }
@@ -154,15 +153,13 @@ public class ErrorMessageTest extends BaseTest {
           || sharedOptions().useServerPrepStmts
           || sharedOptions().rewriteBatchedStatements) {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
       } else {
         assertTrue(
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains(
                     "INSERT INTO testErrorMessage(test, test2) values "
@@ -182,7 +179,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values " + "(?, ?)"));
     }
@@ -197,7 +193,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
     }
@@ -214,26 +209,23 @@ public class ErrorMessageTest extends BaseTest {
           || sharedOptions().useServerPrepStmts
           || sharedOptions().rewriteBatchedStatements) {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
       } else {
         if (!sharedOptions().useBatchMultiSend) {
           assertTrue(
-              "message : " + sqle.getCause().getCause().getMessage(),
+              "message : " + sqle.getCause().getMessage(),
               sqle.getCause()
-                  .getCause()
                   .getMessage()
                   .contains(
                       "INSERT INTO testErrorMessage(test, test2) "
                           + "values (?, ?), parameters ['more than 10 characters to provoc error',200]"));
         } else {
           assertTrue(
-              "message : " + sqle.getCause().getCause().getMessage(),
+              "message : " + sqle.getCause().getMessage(),
               sqle.getCause()
-                  .getCause()
                   .getMessage()
                   .contains(
                       "INSERT INTO testErrorMessage(test, test2) values "
@@ -253,16 +245,14 @@ public class ErrorMessageTest extends BaseTest {
       sqle.printStackTrace();
       if (isMariadbServer() && minVersion(10, 2)) {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
       } else {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains(
                     "INSERT INTO testErrorMessage(test, test2) values (?, ?), "
@@ -283,15 +273,13 @@ public class ErrorMessageTest extends BaseTest {
           || sharedOptions().useServerPrepStmts
           || sharedOptions().rewriteBatchedStatements)) {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
       } else {
         assertTrue(
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains(
                     "INSERT INTO testErrorMessage(test, test2) values "
@@ -311,7 +299,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
     }
@@ -360,7 +347,7 @@ public class ErrorMessageTest extends BaseTest {
 
   @Test
   public void testFailOverKillCmd() throws Throwable {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
     Assume.assumeTrue(isMariadbServer());
     DataSource ds =
         new MariaDbDataSource(
@@ -376,7 +363,11 @@ public class ErrorMessageTest extends BaseTest {
                 + database
                 + "?user="
                 + username
-                + (password != null ? "&password=" + password : ""));
+                + (password != null ? "&password=" + password : "")
+                + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+                + ((options.serverSslCert != null)
+                    ? "&serverSslCert=" + options.serverSslCert
+                    : ""));
 
     try (Connection connection = ds.getConnection()) {
       Protocol protocol = getProtocolFromConnection(connection);
@@ -411,7 +402,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
     }
@@ -428,9 +418,8 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       if (!sharedIsAurora()) {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains(
                     "INSERT INTO testErrorMessage(test, test2) values "
@@ -448,7 +437,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains(
                   "INSERT INTO testErrorMessage(test, test2) values (?, ?), "
@@ -467,7 +455,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains(
                   "INSERT INTO testErrorMessage(test, test2) values "
@@ -487,7 +474,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values " + "(?, ?)"));
     }
@@ -503,7 +489,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
     }
@@ -520,18 +505,16 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       if (!sharedIsAurora()) {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains(
                     "INSERT INTO testErrorMessage(test, test2) values "
                         + "('more than 10 characters to provoc error', 200)"));
       } else {
         assertTrue(
-            "message : " + sqle.getCause().getCause().getMessage(),
+            "message : " + sqle.getCause().getMessage(),
             sqle.getCause()
-                .getCause()
                 .getMessage()
                 .contains(
                     "INSERT INTO testErrorMessage(test, test2) values (?, ?), parameters "
@@ -548,9 +531,8 @@ public class ErrorMessageTest extends BaseTest {
       fail("Must Have thrown error");
     } catch (SQLException sqle) {
       assertTrue(
-          "message : " + sqle.getCause().getCause().getMessage(),
+          "message : " + sqle.getCause().getMessage(),
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains(
                   "INSERT INTO testErrorMessage(test, test2) values (?, ?), parameters "
@@ -569,7 +551,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains(
                   "INSERT INTO testErrorMessage(test, test2) values ("
@@ -589,7 +570,6 @@ public class ErrorMessageTest extends BaseTest {
     } catch (SQLException sqle) {
       assertTrue(
           sqle.getCause()
-              .getCause()
               .getMessage()
               .contains("INSERT INTO testErrorMessage(test, test2) values (?, ?)"));
     }
