@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,14 +52,16 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-import org.mariadb.jdbc.internal.util.constant.*;
-
-import java.sql.*;
-import java.util.*;
-
 import static org.junit.Assert.*;
 
+import java.sql.SQLException;
+import java.util.Arrays;
+import java.util.Properties;
+import org.junit.Test;
+import org.mariadb.jdbc.internal.util.constant.HaMode;
+import org.mariadb.jdbc.internal.util.constant.ParameterConstant;
+import org.mariadb.jdbc.util.Options;
+
 @SuppressWarnings("ConstantConditions")
 public class JdbcParserTest {
 
@@ -130,6 +132,65 @@ public class JdbcParserTest {
     assertTrue(datasource.getUrlParser().auroraPipelineQuirks().getOptions().useBatchMultiSend);
   }
 
+  @Test
+  public void testWrongFormat() {
+    try {
+      UrlParser.parse("jdbc:mariadb:/localhost/test");
+      fail("Must have throw exception");
+    } catch (SQLException ie) {
+      assertTrue(ie.getMessage().contains("url parsing error : '//' is not present in the url"));
+    }
+  }
+
+  @Test
+  public void testNoAdditionalPart() throws SQLException {
+    assertEquals(null, UrlParser.parse("jdbc:mariadb://localhost/").getDatabase());
+    assertEquals(null, UrlParser.parse("jdbc:mariadb://localhost/").getUsername());
+    assertEquals(null, UrlParser.parse("jdbc:mariadb://localhost").getDatabase());
+    assertEquals(null, UrlParser.parse("jdbc:mariadb://localhost").getUsername());
+    assertEquals(null, UrlParser.parse("jdbc:mariadb://localhost?").getDatabase());
+    assertEquals(null, UrlParser.parse("jdbc:mariadb://localhost?").getUsername());
+  }
+
+  @Test
+  public void testDatabaseOnly() throws SQLException {
+    assertEquals("DB", UrlParser.parse("jdbc:mariadb://localhost/DB").getDatabase());
+    assertEquals(null, UrlParser.parse("jdbc:mariadb://localhost/DB").getUsername());
+  }
+
+  @Test
+  public void testUrl() throws SQLException {
+    UrlParser parser =
+        new UrlParser(
+            "DB", Arrays.asList(new HostAddress("local", 3306)), new Options(), HaMode.REPLICATION);
+    assertEquals(
+        "jdbc:mariadb:replication://address=(host=local)(port=3306)(type=master)/DB",
+        parser.getInitialUrl());
+    assertEquals(
+        "jdbc:mariadb:replication://address=(host=local)(port=3306)(type=master)/DB",
+        parser.toString());
+    assertEquals(parser, parser);
+    assertNotEquals(this, parser);
+    assertEquals(
+        UrlParser.parse(
+            "jdbc:mariadb:replication://address=(host=local)(port=3306)(type=master)/DB"),
+        parser);
+
+    parser =
+        new UrlParser(
+            "DB",
+            Arrays.asList(
+                new HostAddress("host1", 3306),
+                new HostAddress("host2", 3307, ParameterConstant.TYPE_SLAVE)),
+            new Options(),
+            HaMode.REPLICATION);
+    assertEquals(
+        "jdbc:mariadb:replication://address=(host=host1)(port=3306)(type=master),address=(host=host2)(port=3307)(type=slave)/DB",
+        parser.getInitialUrl());
+    parser.setDatabase("DB2");
+    assertEquals("DB2", parser.getDatabase());
+  }
+
   @Test
   public void testAuroraUsePipelineAuth() throws Throwable {
     assertTrue(
