@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -22,18 +22,24 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-import org.mariadb.jdbc.internal.util.pool.*;
-import org.mariadb.jdbc.internal.util.scheduler.*;
-
-import javax.management.*;
-import java.lang.management.*;
-import java.sql.*;
-import java.util.*;
-import java.util.concurrent.*;
-
 import static org.junit.Assert.*;
 
+import java.lang.management.ManagementFactory;
+import java.sql.*;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+import javax.management.MBeanInfo;
+import javax.management.MBeanServer;
+import javax.management.ObjectName;
+import org.junit.Assume;
+import org.junit.Test;
+import org.mariadb.jdbc.internal.util.pool.Pools;
+import org.mariadb.jdbc.internal.util.scheduler.MariaDbThreadFactory;
+
 public class MariaDbPoolDataSourceTest extends BaseTest {
 
   @Test
@@ -215,7 +221,7 @@ public class MariaDbPoolDataSourceTest extends BaseTest {
 
   @Test
   public void testResetTransactionIsolation() throws SQLException {
-    Assume.assumeFalse(sharedIsAurora());
+    Assume.assumeTrue(!sharedIsAurora() && System.getenv("SKYSQL") == null);
     try (MariaDbPoolDataSource pool = new MariaDbPoolDataSource(connUri + "&maxPoolSize=1")) {
 
       try (Connection connection = pool.getConnection()) {
@@ -291,6 +297,7 @@ public class MariaDbPoolDataSourceTest extends BaseTest {
     // appveyor is so slow wait time are not relevant.
     Assume.assumeTrue(
         System.getenv("MAXSCALE_VERSION") == null
+            && System.getenv("SKYSQL") == null
             && System.getenv("APPVEYOR_BUILD_WORKER_IMAGE") == null);
 
     MBeanServer server = ManagementFactory.getPlatformMBeanServer();
@@ -402,6 +409,7 @@ public class MariaDbPoolDataSourceTest extends BaseTest {
 
   @Test
   public void ensureUsingPool() throws Exception {
+    Assume.assumeTrue(System.getenv("SKYSQL") == null);
     ThreadPoolExecutor connectionAppender =
         new ThreadPoolExecutor(
             50,
