@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,18 +52,20 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
+import static org.junit.Assert.*;
 
 import java.sql.*;
-import java.util.*;
-
-import static org.junit.Assert.*;
+import java.util.Properties;
+import org.junit.Assume;
+import org.junit.BeforeClass;
+import org.junit.Test;
 
 public class MultiTest extends BaseTest {
 
   /** Tables initialisation. */
   @BeforeClass()
   public static void initClass() throws SQLException {
+    System.out.println("DIEGO MultiTest initClass BEGIN");
     createTable("MultiTestt1", "id int, test varchar(100)");
     createTable("MultiTestt2", "id int, test varchar(100)");
     createTable("MultiTestt3", "message text");
