@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,12 +52,16 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
-import javax.sql.*;
-import java.sql.*;
-
-import static org.junit.Assert.*;
+import java.sql.Connection;
+import java.sql.PreparedStatement;
+import java.sql.SQLException;
+import javax.sql.ConnectionPoolDataSource;
+import javax.sql.PooledConnection;
+import org.junit.Assume;
+import org.junit.Test;
 
 public class PooledConnectionTest extends BaseTest {
 
@@ -84,7 +88,7 @@ public class PooledConnectionTest extends BaseTest {
 
   @Test(expected = SQLException.class)
   public void testPooledConnectionException() throws Exception {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
+    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
 
     ConnectionPoolDataSource ds =
         new MariaDbDataSource(hostname != null ? hostname : "localhost", port, database);
@@ -115,6 +119,7 @@ public class PooledConnectionTest extends BaseTest {
 
   @Test
   public void testPooledConnectionStatementError() throws Exception {
+    Assume.assumeFalse(options.useSsl != null && options.useSsl);
     ConnectionPoolDataSource ds =
         new MariaDbDataSource(hostname != null ? hostname : "localhost", port, database);
     PooledConnection pc = ds.getPooledConnection(username, password);
