@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,13 +52,14 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-
-import java.math.*;
-import java.sql.*;
-
 import static org.junit.Assert.*;
 
+import java.math.BigInteger;
+import java.sql.*;
+import org.junit.Assume;
+import org.junit.BeforeClass;
+import org.junit.Test;
+
 public class PreparedStatementTest extends BaseTest {
 
   private static final int ER_NO_SUCH_TABLE = 1146;
