@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,11 +52,13 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
+import static org.junit.Assert.*;
 
 import java.sql.*;
-
-import static org.junit.Assert.*;
+import org.junit.Assert;
+import org.junit.Assume;
+import org.junit.BeforeClass;
+import org.junit.Test;
 
 public class ResultSetTest extends BaseTest {
 
@@ -1194,19 +1196,31 @@ public class ResultSetTest extends BaseTest {
 
   @Test
   public void columnNamesMappingError() throws SQLException {
-    createTable("columnNamesMappingError", "xx tinyint(1)");
+    createTable(
+        "columnNamesMappingError", "xX INT NOT NULL AUTO_INCREMENT, " + "  PRIMARY KEY(xX)");
+
     Statement stmt = sharedConnection.createStatement();
     stmt.executeUpdate("INSERT INTO columnNamesMappingError VALUES (4)");
-    ResultSet rs = stmt.executeQuery("SELECT * FROM columnNamesMappingError");
-    assertTrue(rs.next());
-    assertEquals(4, rs.getInt("xx"));
-    try {
-      rs.getInt("wrong_column_name");
-      fail("must have fail, column 'wrong_column_name' does not exists");
-    } catch (SQLException e) {
-      assertEquals("42S22", e.getSQLState());
-      assertEquals(1054, e.getErrorCode());
-      assertEquals("No such column: wrong_column_name", e.getMessage());
+    try (PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement(
+            "SELECT * FROM " + "columnNamesMappingError",
+            ResultSet.TYPE_FORWARD_ONLY,
+            ResultSet.CONCUR_UPDATABLE)) {
+      ResultSet rs = preparedStatement.executeQuery();
+      assertTrue(rs.next());
+      assertEquals(4, rs.getInt("xx"));
+      try {
+        rs.getInt("wrong_column_name");
+        fail("must have fail, column 'wrong_column_name' does not exists");
+      } catch (SQLException e) {
+        assertEquals("42S22", e.getSQLState());
+        assertEquals(1054, e.getErrorCode());
+        assertTrue(
+            e.getMessage()
+                .contains(
+                    "No such column: 'wrong_column_name'. 'wrong_column_name' must be in "
+                        + "[xx, columnnamesmappingerror.xx]"));
+      }
     }
   }
 
