@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -27,13 +27,12 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-
-import java.math.*;
-import java.sql.*;
-
 import static org.junit.Assert.*;
 
+import java.math.BigInteger;
+import java.sql.*;
+import org.junit.Test;
+
 public class ScalarFunctionsTest extends BaseTest {
 
   @Test
@@ -183,4 +182,18 @@ public class ScalarFunctionsTest extends BaseTest {
       }
     }
   }
+
+  @Test
+  public void doubleBackslash() throws SQLException {
+    Statement stmt = sharedConnection.createStatement();
+    stmt.execute("DROP TABLE IF EXISTS TEST_SYNTAX_ERROR");
+    stmt.execute(
+        "CREATE TABLE TEST_SYNTAX_ERROR("
+            + "     id INTEGER unsigned NOT NULL AUTO_INCREMENT, "
+            + "     str_value MEDIUMTEXT CHARACTER SET utf8mb4 NOT NULL,"
+            + "     json_value  MEDIUMTEXT CHARACTER SET utf8mb4 NOT NULL, "
+            + "    PRIMARY KEY ( id ))");
+    stmt.execute(
+        "INSERT INTO TEST_SYNTAX_ERROR(str_value, json_value) VALUES ('abc\\\\', '{\"data\": \"test\"}')");
+  }
 }
