@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,16 +52,20 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-
-import java.io.*;
-import java.lang.reflect.*;
-import java.sql.*;
-import java.util.*;
-
-import static org.hamcrest.CoreMatchers.*;
 import static org.junit.Assert.*;
 
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.InputStream;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.sql.*;
+import java.util.Properties;
+import org.junit.Assume;
+import org.junit.Before;
+import org.junit.BeforeClass;
+import org.junit.Test;
+
 public class StoredProcedureTest extends BaseTest {
 
   /**
@@ -381,7 +385,7 @@ public class StoredProcedureTest extends BaseTest {
         stmt.setDouble("a", tooMuch);
         try (ResultSet rs2 = stmt.executeQuery()) {
           assertTrue(rs2.next());
-          assertThat(rs2.getDouble(1), is(not(tooMuch)));
+          assertNotEquals(rs2.getDouble(1), tooMuch);
         }
       }
     }
@@ -413,7 +417,9 @@ public class StoredProcedureTest extends BaseTest {
     }
     statement.execute("CREATE USER 'test_jdbc'@'%' IDENTIFIED BY 'testJ@dc1'");
     statement.execute(
-        "GRANT ALL PRIVILEGES ON testj.* TO 'test_jdbc'@'%' IDENTIFIED BY 'testJ@dc1' WITH GRANT OPTION");
+        "GRANT SELECT, EXECUTE  ON "
+            + database
+            + ".* TO 'test_jdbc'@'%' IDENTIFIED BY 'testJ@dc1' WITH GRANT OPTION");
     Properties properties = new Properties();
     properties.put("user", "test_jdbc");
     properties.put("password", "testJ@dc1");
@@ -1656,4 +1662,18 @@ public class StoredProcedureTest extends BaseTest {
       assertFalse(st3.execute());
     }
   }
+
+  @Test
+  public void testTimestampParameterOutput() throws Exception {
+    createProcedure(
+        "CONJ791", "(IN a TEXT, OUT b DATETIME) \nBEGIN\nSET b := '2006-01-01 01:01:16';\nEND");
+
+    // registering with VARCHAR Type
+    CallableStatement cstmt = sharedConnection.prepareCall("{call CONJ791(?, ?)}");
+    cstmt.setString(1, "o");
+    cstmt.registerOutParameter(2, Types.TIMESTAMP);
+    cstmt.execute();
+
+    assertEquals(Timestamp.valueOf("2006-01-01 01:01:16"), cstmt.getTimestamp(2));
+  }
 }
