@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,13 +52,14 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
-
-import java.io.*;
-import java.sql.*;
-
 import static org.junit.Assert.*;
 
+import java.io.ByteArrayInputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.sql.*;
+import org.junit.Test;
+
 public class UpdateResultSetTest extends BaseTest {
 
   /**
@@ -223,7 +224,7 @@ public class UpdateResultSetTest extends BaseTest {
   }
 
   @Test
-  public void testUpdateWithoutPrimary() throws Exception {
+  public void testMeta() throws Exception {
     createTable(
         "UpdateWithoutPrimary",
         "`id` INT NOT NULL AUTO_INCREMENT,"
@@ -264,6 +265,33 @@ public class UpdateResultSetTest extends BaseTest {
                     "ResultSet cannot be updated. "
                         + "Primary key field `id` is not in result-set"));
       }
+      ResultSetMetaData rsmd = rs.getMetaData();
+      assertFalse(rsmd.isReadOnly(1));
+      assertFalse(rsmd.isReadOnly(2));
+      assertTrue(rsmd.isWritable(1));
+      assertTrue(rsmd.isWritable(2));
+      assertTrue(rsmd.isDefinitelyWritable(1));
+      assertTrue(rsmd.isDefinitelyWritable(2));
+
+      try {
+        rsmd.isReadOnly(3);
+        fail("must have throw exception");
+      } catch (SQLException sqle) {
+        System.out.println(sqle.getMessage());
+        assertTrue(sqle.getMessage().contains("wrong column index 3. must be in [1, 2] range"));
+      }
+      try {
+        rsmd.isWritable(3);
+        fail("must have throw exception");
+      } catch (SQLException sqle) {
+        assertTrue(sqle.getMessage().contains("wrong column index 3. must be in [1, 2] range"));
+      }
+      try {
+        rsmd.isDefinitelyWritable(3);
+        fail("must have throw exception");
+      } catch (SQLException sqle) {
+        assertTrue(sqle.getMessage().contains("wrong column index 3. must be in [1, 2] range"));
+      }
     }
     int[] autoInc = setAutoInc();
     ResultSet rs = stmt.executeQuery("SELECT id, t1, t2 FROM UpdateWithoutPrimary");
@@ -275,62 +303,6 @@ public class UpdateResultSetTest extends BaseTest {
     assertFalse(rs.next());
   }
 
-  @Test
-  public void testUpdateWithPrimary() throws Exception {
-    createTable(
-        "testUpdateWithPrimary",
-        "`id` INT NOT NULL AUTO_INCREMENT,"
-            + "`t1` VARCHAR(50) NOT NULL,"
-            + "`t2` VARCHAR(50) NULL default 'default-value',"
-            + "PRIMARY KEY (`id`)",
-        "DEFAULT CHARSET=utf8");
-
-    Statement stmt = sharedConnection.createStatement();
-    stmt.executeQuery(
-        "INSERT INTO testUpdateWithPrimary(t1,t2) values ('1-1','1-2'),('2-1','2-2')");
-
-    String utf8escapeQuote = "你好 '\' \" \\";
-
-    try (PreparedStatement preparedStatement =
-        sharedConnection.prepareStatement(
-            "SELECT id, t1, t2 FROM testUpdateWithPrimary",
-            ResultSet.TYPE_FORWARD_ONLY,
-            ResultSet.CONCUR_UPDATABLE)) {
-      ResultSet rs = preparedStatement.executeQuery();
-
-      rs.moveToInsertRow();
-      rs.updateInt(1, -1);
-      rs.updateString(2, "0-1");
-      rs.updateString(3, "0-2");
-      rs.insertRow();
-
-      assertTrue(rs.next());
-      assertTrue(rs.next());
-      rs.updateString(2, utf8escapeQuote);
-      rs.updateRow();
-    }
-
-    final int[] autoInc = setAutoInc();
-
-    ResultSet rs = stmt.executeQuery("SELECT id, t1, t2 FROM testUpdateWithPrimary");
-    assertTrue(rs.next());
-    assertEquals(-1, rs.getInt(1));
-    assertEquals("0-1", rs.getString(2));
-    assertEquals("0-2", rs.getString(3));
-
-    assertTrue(rs.next());
-    assertEquals(autoInc[0] + autoInc[1], rs.getInt(1));
-    assertEquals("1-1", rs.getString(2));
-    assertEquals("1-2", rs.getString(3));
-
-    assertTrue(rs.next());
-    assertEquals(2 * autoInc[0] + autoInc[1], rs.getInt(1));
-    assertEquals(utf8escapeQuote, rs.getString(2));
-    assertEquals("2-2", rs.getString(3));
-
-    assertFalse(rs.next());
-  }
-
   @Test
   public void testUpdateWhenFetch() throws Exception {
     createTable(
@@ -351,7 +323,7 @@ public class UpdateResultSetTest extends BaseTest {
     }
     pstmt.executeBatch();
 
-    String utf8escapeQuote = "你好 '\' \" \\";
+    String utf8escapeQuote = "你好 '' \" \\";
     try (PreparedStatement preparedStatement =
         sharedConnection.prepareStatement(
             "SELECT id, t1, t2 FROM testUpdateWhenFetch",
