@@ -1,13 +1,15 @@
 package org.mariadb.jdbc.internal.protocol.tls;
 
-import org.junit.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
 
-import javax.net.ssl.*;
-import javax.security.auth.x500.*;
-import java.io.*;
-import java.security.cert.*;
-
-import static org.junit.Assert.*;
+import java.io.ByteArrayInputStream;
+import java.security.cert.CertificateException;
+import java.security.cert.CertificateFactory;
+import java.security.cert.X509Certificate;
+import javax.net.ssl.SSLException;
+import javax.security.auth.x500.X500Principal;
+import org.junit.Test;
 
 public class HostnameVerifierImplTest {
 
