@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,11 +52,12 @@
 
 package org.mariadb.jdbc.internal.util;
 
-import org.junit.*;
-import org.mariadb.jdbc.internal.com.send.parameters.*;
-
 import static org.junit.Assert.*;
 
+import org.junit.Test;
+import org.mariadb.jdbc.internal.com.send.parameters.ParameterHolder;
+import org.mariadb.jdbc.internal.com.send.parameters.StringParameter;
+
 public class UtilsTest {
 
   @Test
@@ -74,12 +75,15 @@ public class UtilsTest {
           0x6C, 0x5F, 0x6D, 0x6F, 0x64, 0x65
         };
     String result =
-        "\n"
-            + "4A 00 00 00 03 53 45 4C  45 43 54 20 40 40 6D 61     J....SELECT @@ma\n"
-            + "78 5F 61 6C 6C 6F 77 65  64 5F 70 61 63 6B 65 74     x_allowed_packet\n"
-            + "20 2C 20 40 40 73 79 73  74 65 6D 5F 74 69 6D 65      , @@system_time\n"
-            + "5F 7A 6F 6E 65 2C 20 40  40 74 69 6D 65 5F 7A 6F     _zone, @@time_zo\n"
-            + "6E 65 2C 20 40 40 73 71  6C 5F 6D 6F 64 65           ne, @@sql_mode\n";
+        "\n+--------------------------------------------------+\n"
+            + "|  0  1  2  3  4  5  6  7   8  9  a  b  c  d  e  f |\n"
+            + "+--------------------------------------------------+------------------+\n"
+            + "| 4A 00 00 00 03 53 45 4C  45 43 54 20 40 40 6D 61 | J....SELECT @@ma |\n"
+            + "| 78 5F 61 6C 6C 6F 77 65  64 5F 70 61 63 6B 65 74 | x_allowed_packet |\n"
+            + "| 20 2C 20 40 40 73 79 73  74 65 6D 5F 74 69 6D 65 |  , @@system_time |\n"
+            + "| 5F 7A 6F 6E 65 2C 20 40  40 74 69 6D 65 5F 7A 6F | _zone, @@time_zo |\n"
+            + "| 6E 65 2C 20 40 40 73 71  6C 5F 6D 6F 64 65       | ne, @@sql_mode   |\n"
+            + "+--------------------------------------------------+------------------+\n";
     assertEquals(result, Utils.hexdump(bb));
   }
 
